@@ -1,5 +1,6 @@
 # -*- coding:utf-8 -*-
 import locale
+
 locale.setlocale(locale.LC_ALL, "fr_FR.UTF-8")
 locale.setlocale(locale.LC_TIME, "fr_FR.UTF-8")
 
@@ -18,14 +19,11 @@ from endi_base.models.initialize import initialize_sql
 from endi_celery.tasks.csv_import import (
     MODELS_CONFIGURATION as IMPORT_MODELS_CONFIGURATION,
 )
-from endi_celery.tasks.export import (
-    MODELS_CONFIGURATION as EXPORT_MODELS_CONFIGURATION
-)
+from endi_celery.tasks.export import MODELS_CONFIGURATION as EXPORT_MODELS_CONFIGURATION
 
 
 def register_import_model(
-    config, key, model, label, permission, excludes,
-    callbacks=()
+    config, key, model, label, permission, excludes, callbacks=()
 ):
     """
     Register a model for import
@@ -40,11 +38,11 @@ def register_import_model(
     :param list callbacks: List of callables called after import action
     """
     IMPORT_MODELS_CONFIGURATION[key] = {
-        'factory': model,
-        'label': label,
-        'permission': permission,
-        'excludes': excludes,
-        'callbacks': callbacks,
+        "factory": model,
+        "label": label,
+        "permission": permission,
+        "excludes": excludes,
+        "callbacks": callbacks,
     }
 
 
@@ -56,7 +54,7 @@ def register_export_model(config, key, model, options={}):
     :param str key: The key used to identify the model type
     :param class model: The model to be used
     """
-    EXPORT_MODELS_CONFIGURATION[key] = {'factory': model}
+    EXPORT_MODELS_CONFIGURATION[key] = {"factory": model}
     EXPORT_MODELS_CONFIGURATION[key].update(options)
 
 
@@ -74,34 +72,32 @@ def worker(global_config, **settings):
     Entry point for the pyramid celery stuff
     """
     logging.basicConfig()
-    setup_logging(global_config['__file__'])
+    setup_logging(global_config["__file__"])
     logger = logging.getLogger(__name__)
     logger.info("Bootstraping app")
-    engine = engine_from_config(settings, 'sqlalchemy.')
+    engine = engine_from_config(settings, "sqlalchemy.")
     set_cache_regions_from_settings(settings)
     dbsession = initialize_sql(engine)
     config = Configurator(settings=settings)
     # config.include('pyramid_celery')
     includeme(config)
 
-    config.configure_celery(global_config['__file__'])
+    config.configure_celery(global_config["__file__"])
     config.commit()
 
-    config = prepare_view_config(
-        config, dbsession, from_tests=False, **settings
-    )
+    config = prepare_view_config(config, dbsession, from_tests=False, **settings)
     configure_filedepot(settings)
-    config.include('endi.views.files')
+    config.include("endi.views.files")
     return config.make_wsgi_app()
 
 
 def scheduler(global_config, **settings):
     logging.basicConfig()
-    setup_logging(global_config['__file__'])
+    setup_logging(global_config["__file__"])
     logger = logging.getLogger(__name__)
     logger.info("Bootstraping celery scheduler application")
     config = Configurator(settings=settings)
-    config.include('pyramid_celery')
-    config.configure_celery(global_config['__file__'])
+    config.include("pyramid_celery")
+    config.configure_celery(global_config["__file__"])
     config.commit()
     return config.make_wsgi_app()
