@@ -55,6 +55,7 @@ class GridCacheItem:
     total value by measure_type
     total value by measure type category
     """
+
     def __init__(self, grid):
         self.grid = grid
         self._category_totals = {}
@@ -71,11 +72,13 @@ class GridCacheItem:
         :returns: The list of measures to remove
         """
         old_measures = [
-            measure for measure in self.grid.measures
+            measure
+            for measure in self.grid.measures
             if measure.measure_type_id not in type_ids
         ]
         self.grid.measures = [
-            measure for measure in self.grid.measures
+            measure
+            for measure in self.grid.measures
             if measure.measure_type_id in type_ids
         ]
 
@@ -146,6 +149,7 @@ class GridCache:
     Eache item is an Accounting Measure Grid wraped with the GridCacheItem
     object
     """
+
     def __init__(self):
         self._datas = {}
 
@@ -172,6 +176,7 @@ class BaseMeasureCompiler(object):
     Totals are used in a second time to compute "total" measures
     (not related to account numbers)
     """
+
     measure_type_class = None
     measure_type_category_class = None
     measure_grid_class = None
@@ -200,13 +205,11 @@ class BaseMeasureCompiler(object):
         Build a query to list active measure types
         :returns: An sqlalchemy query object
         """
-        return self.measure_type_class.query(
-        ).join(
-            self.measure_type_category_class
-        ).filter(
-            self.measure_type_class.active == True  # noqa: E712
-        ).filter(
-            self.measure_type_category_class.active == True  # noqa: E712
+        return (
+            self.measure_type_class.query()
+            .join(self.measure_type_category_class)
+            .filter(self.measure_type_class.active == True)  # noqa: E712
+            .filter(self.measure_type_category_class.active == True)  # noqa: E712
         )
 
     def _collect_common_measure_types(self):
@@ -214,12 +217,16 @@ class BaseMeasureCompiler(object):
         Retrieve measure types that are not computed from other measures
         :returns: The list of measure types
         """
-        return self._get_active_type_query().filter(
-            or_(
-                self.measure_type_class.is_total == False,  # noqa: E712
-                self.measure_type_class.total_type == 'account_prefix',
+        return (
+            self._get_active_type_query()
+            .filter(
+                or_(
+                    self.measure_type_class.is_total == False,  # noqa: E712
+                    self.measure_type_class.total_type == "account_prefix",
+                )
             )
-        ).all()
+            .all()
+        )
 
     def _collect_categories(self):
         """
@@ -235,13 +242,16 @@ class BaseMeasureCompiler(object):
         """
         result = OrderedDict()
         query = self._get_active_type_query()
-        query = query.filter(
-            self.measure_type_class.is_total == True,  # noqa: E712
-        ).filter(
-            self.measure_type_class.total_type != 'account_prefix',
-        ).order_by(
-            self.measure_type_category_class.order
-        ).order_by(self.measure_type_class.order)
+        query = (
+            query.filter(
+                self.measure_type_class.is_total == True,  # noqa: E712
+            )
+            .filter(
+                self.measure_type_class.total_type != "account_prefix",
+            )
+            .order_by(self.measure_type_category_class.order)
+            .order_by(self.measure_type_class.order)
+        )
         for typ in query:
             result.setdefault(typ.category_id, []).append(typ)
         return result
@@ -344,9 +354,7 @@ class BaseMeasureCompiler(object):
 
         :returns: A list of GridCacheItem
         """
-        logger.debug(
-            "    + Processing datas with {}".format(self.__class__.__name__)
-        )
+        logger.debug("    + Processing datas with {}".format(self.__class__.__name__))
         for operation in self.operations:
             if operation.company_id is None:
                 continue
@@ -369,7 +377,9 @@ class BaseMeasureCompiler(object):
                         )
                         current_grid_item.store_measure(measure)
 
-                    measure.value += operation.total()
+                    operation_sign = measure_type.sign()
+
+                    measure.value += operation_sign * operation.total()
                     matched = True
 
                 if matched:
@@ -397,8 +407,7 @@ class BaseMeasureCompiler(object):
                     logger.debug(
                         "Updating the order of the given measure {} :"
                         " was {} becomes {}".format(
-                            measure.label, measure.order,
-                            measure_type.order
+                            measure.label, measure.order, measure_type.order
                         )
                     )
                     measure.order = measure_type.order
@@ -412,8 +421,7 @@ class BaseMeasureCompiler(object):
         """
         for grid_item in self.processed_grids:
             measures = grid_item.get_measures()
-            for category_id, measure_types in \
-                    self.computed_measure_types.items():
+            for category_id, measure_types in self.computed_measure_types.items():
                 for measure_type in measure_types:
                     values = self.get_values_for_computation(grid_item)
                     value = measure_type.compute_total(values)
@@ -460,7 +468,9 @@ class TreasuryMeasureCompiler(BaseMeasureCompiler):
 
 ----
 enDI
-""".format(len(grids))
+""".format(
+            len(grids)
+        )
 
     def get_cache_key_from_operation(self, operation):
         """
@@ -482,13 +492,13 @@ enDI
 
         Query filters should match the get_cache_key_from_operation options
         """
-        query = TreasuryMeasureGrid.query().filter_by(
-            date=self.upload.updated_at.date()
-        ).filter_by(company_id=operation.company_id)
-
-        query = query.order_by(
-            desc(TreasuryMeasureGrid.datetime)
+        query = (
+            TreasuryMeasureGrid.query()
+            .filter_by(date=self.upload.updated_at.date())
+            .filter_by(company_id=operation.company_id)
         )
+
+        query = query.order_by(desc(TreasuryMeasureGrid.datetime))
         return query.first()
 
     def _get_new_grid(self, operation):
@@ -528,17 +538,15 @@ Comptes de résultat traités : {}
 
 ----
 enDI
-""".format(int(len(grids)/12))
+""".format(
+            int(len(grids) / 12)
+        )
 
     def get_cache_key_from_operation(self, operation):
         """
         Build a cache key based on the given operation object
         """
-        return (
-            operation.company_id,
-            operation.date.year,
-            operation.date.month
-        )
+        return (operation.company_id, operation.date.year, operation.date.month)
 
     def get_cache_key_from_grid(self, grid):
         """
@@ -552,11 +560,13 @@ enDI
 
         Query filters should match the get_cache_key_from_operation options
         """
-        return IncomeStatementMeasureGrid.query().filter_by(
-            year=operation.date.year
-        ).filter_by(
-            month=operation.date.month
-        ).filter_by(company_id=operation.company_id).first()
+        return (
+            IncomeStatementMeasureGrid.query()
+            .filter_by(year=operation.date.year)
+            .filter_by(month=operation.date.month)
+            .filter_by(company_id=operation.company_id)
+            .first()
+        )
 
     def _get_new_grid(self, operation):
         """
@@ -600,10 +610,7 @@ enDI
 
         # Choosing which date has to be used
         date_to_set = None
-        if(
-            self.upload.filetype ==
-            AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
-        ):
+        if self.upload.filetype == AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
             date_to_set = self.upload.updated_at
         else:
             date_to_set = self.upload.created_at
@@ -633,9 +640,9 @@ def get_measure_compilers(data_type, grid_type=None):
         return [TreasuryMeasureCompiler, IncomeStatementMeasureCompiler]
     elif data_type == AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
         logger.info("  + Handling Synchronized Datas")
-        if grid_type == 'treasury':
+        if grid_type == "treasury":
             return [TreasuryMeasureCompiler]
-        elif grid_type == 'income_statement':
+        elif grid_type == "income_statement":
             return [IncomeStatementMeasureCompiler]
         else:
             return [TreasuryMeasureCompiler, IncomeStatementMeasureCompiler]
@@ -698,33 +705,32 @@ def _collect_operations(upload_id, data_type, upload_date):
 
     closure_day = 0
     closure_month = 0
-    if(
-        config.get("accounting_closure_day") is not None and
-        config.get("accounting_closure_month") is not None
+    if (
+        config.get("accounting_closure_day") is not None
+        and config.get("accounting_closure_month") is not None
     ):
         closure_day = int("0" + str(config.get("accounting_closure_day")))
         closure_month = int("0" + str(config.get("accounting_closure_month")))
 
     # If days and month not set, assume that closure is at the end of the year
-    if(closure_day == 0 or closure_month == 0):
-        logger.info(u"Accounting closure day or month not set, assuming closure\
-                is on 31/12")
+    if closure_day == 0 or closure_month == 0:
+        logger.info(
+            u"Accounting closure day or month not set, assuming closure\
+                is on 31/12"
+        )
         closure_day = 31
         closure_month = 12
 
     # Find exercice begining day and month
-    temp_date = date(current_year, closure_month, closure_day) +\
-        datetime.timedelta(days=1)
+    temp_date = date(current_year, closure_month, closure_day) + datetime.timedelta(
+        days=1
+    )
     begining_day = temp_date.day
     begining_month = temp_date.month
 
     # Collecting operation for current exercice fiscal
-    current_exercice_begining_date = date(
-        current_year, begining_month, begining_day
-    )
-    current_exercice_end_date = date(
-        current_year, closure_month, closure_day
-    )
+    current_exercice_begining_date = date(current_year, begining_month, begining_day)
+    current_exercice_end_date = date(current_year, closure_month, closure_day)
 
     # If closure day is not 31/12 we have an exercice overlaping two years
     if not (closure_day == 31 and closure_month == 12):
@@ -736,83 +742,109 @@ def _collect_operations(upload_id, data_type, upload_date):
         if this_month > closure_month:
             today_is_after_the_closure = True
         elif this_month == closure_month:
-            if(this_day > closure_day):
+            if this_day > closure_day:
                 today_is_after_the_closure = True
             else:
                 today_is_after_the_closure = False
         else:
             today_is_after_the_closure = False
 
-        logger.info("Today is after the closure this year :\
-                {}".format(today_is_after_the_closure))
+        logger.info(
+            "Today is after the closure this year :\
+                {}".format(
+                today_is_after_the_closure
+            )
+        )
 
         # If so or not we set the corresponding exercice dates
         if today_is_after_the_closure:
-            current_exercice_begining_date =\
-                    current_exercice_begining_date.replace(year=current_year)
-            current_exercice_end_date = current_exercice_end_date + \
-                relativedelta(years=1)
+            current_exercice_begining_date = current_exercice_begining_date.replace(
+                year=current_year
+            )
+            current_exercice_end_date = current_exercice_end_date + relativedelta(
+                years=1
+            )
         else:
-            current_exercice_begining_date = current_exercice_begining_date -\
-                    relativedelta(years=1)
-            current_exercice_end_date = \
-                current_exercice_end_date.replace(year=current_year)
+            current_exercice_begining_date = (
+                current_exercice_begining_date - relativedelta(years=1)
+            )
+            current_exercice_end_date = current_exercice_end_date.replace(
+                year=current_year
+            )
 
-    logger.info("Current exercice start the {} and ends the\
-            {}".format(current_exercice_begining_date,
-                current_exercice_end_date))
-
-    current_exercice_operations = AccountingOperation.query().filter(
-        AccountingOperation.date.between(
-            current_exercice_begining_date,
-            current_exercice_end_date
+    logger.info(
+        "Current exercice start the {} and ends the\
+            {}".format(
+            current_exercice_begining_date, current_exercice_end_date
         )
-    ).all()
+    )
 
-    logger.debug(u"{} operations\
-            collected".format(len(current_exercice_operations)))
+    current_exercice_operations = (
+        AccountingOperation.query()
+        .filter(
+            AccountingOperation.date.between(
+                current_exercice_begining_date, current_exercice_end_date
+            )
+        )
+        .all()
+    )
+
+    logger.debug(
+        u"{} operations\
+            collected".format(
+            len(current_exercice_operations)
+        )
+    )
 
     # Adding last exercice operations if needed (dans les cas ou les report
     # d'à nouveau n'ont pas encore été fait)
     # Only for synchronised  operations (remontée automatique)
-    if(data_type != AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING):
+    if data_type != AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
         return current_exercice_operations
 
     # Look into AccountingClosure model to check if closure for current year
     # has been done
-    former_year_closure = AccountingClosure.query().filter_by(
-        year=former_closure_year
-    ).first()
+    former_year_closure = (
+        AccountingClosure.query().filter_by(year=former_closure_year).first()
+    )
 
     closure_is_done = False
     if former_year_closure:
         closure_is_done = former_year_closure.active
 
-    logger.info(
-        u"{} closure is done : {}".format(former_closure_year, closure_is_done)
-    )
+    logger.info(u"{} closure is done : {}".format(former_closure_year, closure_is_done))
 
     if not closure_is_done:
         # Find date of last exercice
-        last_exercice_begining_date = current_exercice_begining_date -\
-            relativedelta(years=1)
-        last_exercice_end_date = current_exercice_end_date -\
-            relativedelta(years=1)
+        last_exercice_begining_date = current_exercice_begining_date - relativedelta(
+            years=1
+        )
+        last_exercice_end_date = current_exercice_end_date - relativedelta(years=1)
 
-        logger.info("Last exercice start the {} and ends the\
-                {}".format(last_exercice_begining_date,
-                    last_exercice_end_date))
+        logger.info(
+            "Last exercice start the {} and ends the\
+                {}".format(
+                last_exercice_begining_date, last_exercice_end_date
+            )
+        )
 
         # Select operations from last "exercice"
-        last_exercice_operations = AccountingOperation.query().filter(
-            AccountingOperation.date.between(
-                last_exercice_begining_date,
-                last_exercice_end_date
+        last_exercice_operations = (
+            AccountingOperation.query()
+            .filter(
+                AccountingOperation.date.between(
+                    last_exercice_begining_date, last_exercice_end_date
+                )
             )
-        ).all()
+            .all()
+        )
 
-        logger.info(u"Appending {} operations from last\
-                exercice".format(len(last_exercice_operations)))
+        logger.info(
+            u"Appending {} operations from last\
+                exercice".format(
+                len(last_exercice_operations)
+            )
+        )
 
         return last_exercice_operations + current_exercice_operations
 
@@ -824,9 +856,7 @@ def compile_measures_task(self, upload_id, grid_type=None):
     """
     Celery task handling measures compilation
     """
-    logger.info(
-        "Launching the compile measure task for upload {0}".format(upload_id)
-    )
+    logger.info("Launching the compile measure task for upload {0}".format(upload_id))
 
     if grid_type is not None:
         logger.info("Only compiling {} grids".format(grid_type))
@@ -835,9 +865,7 @@ def compile_measures_task(self, upload_id, grid_type=None):
     upload = AccountingOperationUpload.get(upload_id)
     if upload is None:
         raise Exception(
-            "No AccountingOperationUpload instance with id {}".format(
-                upload_id
-            )
+            "No AccountingOperationUpload instance with id {}".format(upload_id)
         )
 
     operations = None
@@ -852,9 +880,7 @@ def compile_measures_task(self, upload_id, grid_type=None):
         # trésorerie, à terme quand nous voudrons présenter les comptes de
         # résultat par exercice fiscal elle pourra être également utilisé
         # pour les comptes de résultat.
-        operations = AccountingOperation.query().filter_by(
-            upload_id=upload_id
-        ).all()
+        operations = AccountingOperation.query().filter_by(upload_id=upload_id).all()
 
     mail_addresses = get_recipients_addresses(self.request)
     compiler_factories = get_measure_compilers(upload.filetype, grid_type)
@@ -882,11 +908,7 @@ def compile_measures_task(self, upload_id, grid_type=None):
                 compiler.label,
                 compiler.get_message(grids),
             )
-            logger.info(
-                "A success email has been sent to {0}".format(
-                    mail_addresses
-                )
-            )
+            logger.info("A success email has been sent to {0}".format(mail_addresses))
 
     transaction.commit()
     logger.info("The transaction has been commited")
@@ -906,18 +928,18 @@ def scheduled_compile_measure_task(self, force=False):
         type = crontab
         schedule = {"minute": 0, "hour": 6}
     """
-    logger.info(
-        "Launching scheduled compile measure task for synchronized datas"
-    )
+    logger.info("Launching scheduled compile measure task for synchronized datas")
     yesterday = datetime.date.today() - datetime.timedelta(1)
-    uploads = AccountingOperationUpload.query().filter(
-        AccountingOperationUpload.filetype ==
-        AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
-    ).filter(
-        AccountingOperationUpload.updated_at >= yesterday
-    ).order_by(
-        desc(AccountingOperationUpload.id)
-    ).all()
+    uploads = (
+        AccountingOperationUpload.query()
+        .filter(
+            AccountingOperationUpload.filetype
+            == AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
+        )
+        .filter(AccountingOperationUpload.updated_at >= yesterday)
+        .order_by(desc(AccountingOperationUpload.id))
+        .all()
+    )
     if not uploads:
         logger.info(
             "ABORT : no upload with 'synchronized_accounting' type \
@@ -926,9 +948,7 @@ since yesterday"
     else:
         for upload in uploads:
             transaction.begin()
-            logger.info(
-                "Compiling the measures for upload {} ...".format(upload.id)
-            )
+            logger.info("Compiling the measures for upload {} ...".format(upload.id))
             upload_object = AccountingOperationUpload.get(upload.id)
             measure_compiler_factories = [
                 TreasuryMeasureCompiler,
@@ -940,12 +960,12 @@ since yesterday"
                     operations = _collect_operations(
                         upload.id,
                         upload_object.filetype,
-                        upload_object.created_at.date()
+                        upload_object.created_at.date(),
                     )
                 else:
-                    operations = AccountingOperation.query().filter_by(
-                        upload_id=upload.id
-                    ).all()
+                    operations = (
+                        AccountingOperation.query().filter_by(upload_id=upload.id).all()
+                    )
                 try:
                     measure_compiler = measure_compiler_factory(
                         upload_object, operations
@@ -957,25 +977,18 @@ since yesterday"
                     mail_addresses = get_recipients_addresses(self.request)
                     if mail_addresses:
                         send_error(
-                            self.request,
-                            mail_addresses,
-                            measure_compiler.label,
-                            err
+                            self.request, mail_addresses, measure_compiler.label, err
                         )
                         logger.error(
-                            "An error mail has been sent to {}".format(
-                                mail_addresses
-                            )
+                            "An error mail has been sent to {}".format(mail_addresses)
                         )
-                    logger.exception(
-                        "Transaction has been rollbacked"
-                    )
+                    logger.exception("Transaction has been rollbacked")
                     return False
             transaction.commit()
             logger.info(
                 "SUCCESS : Measure computing transaction has been commited \
-                    for upload {}".format(upload.id)
+                    for upload {}".format(
+                    upload.id
+                )
             )
-        logger.info(
-            "End of scheduled compile measure task for synchronized datas"
-        )
+        logger.info("End of scheduled compile measure task for synchronized datas")
