@@ -40,9 +40,7 @@ from endi_celery.conf import (
     get_recipients_addresses,
 )
 from endi_celery.tasks import utils
-from endi_celery.tasks.accounting_measure_compute import (
-    get_measure_compilers
-)
+from endi_celery.tasks.accounting_measure_compute import get_measure_compilers
 
 
 logger = utils.get_logger(__name__)
@@ -60,7 +58,7 @@ def _get_base_path():
     """
     Retreive the base working path as configured in the ini file
     """
-    return get_setting('endi.parsing_pool_parent', mandatory=True)
+    return get_setting("endi.parsing_pool_parent", mandatory=True)
 
 
 def _get_path(directory):
@@ -92,7 +90,7 @@ def _get_file_path_from_pool(pool_path):
     return result
 
 
-def _get_md5sum(file_path,  blocksize=65536):
+def _get_md5sum(file_path, blocksize=65536):
     """
     Return a md5 sum of the given file_path informations
     """
@@ -103,7 +101,7 @@ def _get_md5sum(file_path,  blocksize=65536):
     return hash.hexdigest()
 
 
-def _mv_file(file_path, queue='processed'):
+def _mv_file(file_path, queue="processed"):
     """
     Move the file to the processed directory
     """
@@ -111,10 +109,12 @@ def _mv_file(file_path, queue='processed'):
         new_dir = _get_path(queue)
         new_file_path = os.path.join(new_dir, os.path.basename(file_path))
         os.system('mv "{0}" "{1}"'.format(file_path, new_file_path))
-        logger.info("The file {0} has been moved to the {1} directory".format(
-            file_path,
-            new_dir,
-        ))
+        logger.info(
+            "The file {0} has been moved to the {1} directory".format(
+                file_path,
+                new_dir,
+            )
+        )
         return new_file_path
     else:
         raise Exception(u"File is missing {}".format(file_path))
@@ -143,8 +143,9 @@ class AccountingDataParser(object):
     """
     Base Accounting datas parser
     """
-    _supported_extensions = ('csv', 'slk')
-    encoding = 'utf-8'
+
+    _supported_extensions = ("csv", "slk")
+    encoding = "utf-8"
 
     # To be filled in subclasses
     _filename_re = None
@@ -155,16 +156,16 @@ class AccountingDataParser(object):
         self.force = force
         self._file_datas = {}
         self._collect_main_file_infos()
-        self.basename = self._file_datas['basename']
+        self.basename = self._file_datas["basename"]
         self.company_id_cache = {}
-        if hasattr(self, '_collect_specific_file_infos'):
+        if hasattr(self, "_collect_specific_file_infos"):
             self._collect_specific_file_infos()
 
     def _load_company_id_cache(self):
-        query = DBSESSION().query(
-            Company.id, Company.code_compta
-        ).filter(
-            Company.code_compta != None  # noqa: E711
+        query = (
+            DBSESSION()
+            .query(Company.id, Company.code_compta)
+            .filter(Company.code_compta != None)  # noqa: E711
         )
         for id_, code in query:
             self.company_id_cache[code] = id_
@@ -186,18 +187,16 @@ class AccountingDataParser(object):
         :returns: A dict containing collected datas
         :rtype: dict
         """
-        basename, extension = os.path.splitext(
-            os.path.basename(self.file_path)
-        )
+        basename, extension = os.path.splitext(os.path.basename(self.file_path))
         if extension:
             extension = extension[1:]
         if extension not in self._supported_extensions:
             raise KnownError(u"L'extension du fichier est inconnue")
 
-        self._file_datas['basename'] = basename
-        self._file_datas['extension'] = extension
-        self._file_datas['md5sum'] = _get_md5sum(self.file_path)
-        self._file_datas['filetype'] = self.filetype
+        self._file_datas["basename"] = basename
+        self._file_datas["extension"] = extension
+        self._file_datas["md5sum"] = _get_md5sum(self.file_path)
+        self._file_datas["filetype"] = self.filetype
         return self._file_datas
 
     def _stream_slk(self):
@@ -213,7 +212,7 @@ class AccountingDataParser(object):
         :returns: An iterator of sheet lines as lists
         """
         with open(self.file_path, encoding=self.encoding) as fbuf:
-            dialect = csv.Sniffer().sniff(fbuf.read(1024))
+            dialect = csv.Sniffer().sniff(fbuf.read())
             fbuf.seek(0)
             for line in csv.reader(fbuf, dialect):
                 yield line
@@ -223,7 +222,7 @@ class AccountingDataParser(object):
         Stream the datas coming from a slk file
         :returns: An iterator for the sheets line
         """
-        extension = self._file_datas['extension']
+        extension = self._file_datas["extension"]
 
         func = getattr(self, "_stream_%s" % extension, None)
         if func is not None:
@@ -247,9 +246,9 @@ class AccountingDataParser(object):
         """
         return AccountingOperationUpload(
             filename=os.path.basename(self.file_path),
-            date=self._file_datas['date'],
-            md5sum=self._file_datas['md5sum'],
-            filetype=self._file_datas['filetype'],
+            date=self._file_datas["date"],
+            md5sum=self._file_datas["md5sum"],
+            filetype=self._file_datas["filetype"],
         )
 
     def _build_operation(self, line_datas):
@@ -295,9 +294,7 @@ class AccountingDataParser(object):
         """
         Return ids of the operations already stored in database
         """
-        return [
-            entry[0] for entry in DBSESSION().query(AccountingOperation.id)
-        ]
+        return [entry[0] for entry in DBSESSION().query(AccountingOperation.id)]
 
     def _get_num_val(self, line, index):
         """
@@ -325,9 +322,7 @@ class AccountingDataParser(object):
             upload_object = self._build_operation_upload_object()
             operations, missed_associations = self._build_operations()
             logger.info(
-                u"Storing {0} new operations in database".format(
-                    len(operations)
-                )
+                u"Storing {0} new operations in database".format(len(operations))
             )
             logger.info(
                 "  + {0} operations were not associated to an existing "
@@ -352,13 +347,10 @@ class AccountingDataParser(object):
 
 class GeneralLedgerParser(AccountingDataParser):
     _filename_re = re.compile(
-        'general_ledger_'
-        '(?P<year>[0-9]+)'
-        '_(?P<month>[^_]+)'
-        '_(?P<doctype>[^_]+)',
-        re.IGNORECASE
+        "general_ledger_" "(?P<year>[0-9]+)" "_(?P<month>[^_]+)" "_(?P<doctype>[^_]+)",
+        re.IGNORECASE,
     )
-    filetype = 'general_ledger'
+    filetype = "general_ledger"
 
     def _collect_specific_file_infos(self):
         """
@@ -370,8 +362,8 @@ class GeneralLedgerParser(AccountingDataParser):
 
         logger.info(u"It's an General Ledger file")
         self._file_datas.update(re_match.groupdict())
-        self._file_datas['date'] = datetime.date(
-            int(self._file_datas['year']), int(self._file_datas['month']), 1
+        self._file_datas["date"] = datetime.date(
+            int(self._file_datas["year"]), int(self._file_datas["month"]), 1
         )
         return self._file_datas
 
@@ -392,9 +384,7 @@ class GeneralLedgerParser(AccountingDataParser):
                 general_account = line_datas[1].strip()
                 date = date_utils.str_to_date(line_datas[2].strip())
                 if not date:
-                    logger.error(
-                        u"This line has incorrect datas : %s" % line_datas
-                    )
+                    logger.error(u"This line has incorrect datas : %s" % line_datas)
                     return None
                 label = line_datas[5].strip()
                 debit = self._get_num_val(line_datas, index=6)
@@ -413,22 +403,20 @@ class GeneralLedgerParser(AccountingDataParser):
                 )
         else:
             if line_datas:
-                logger.error(
-                    u"This line is missing informations : %s" % line_datas
-                )
+                logger.error(u"This line is missing informations : %s" % line_datas)
         return result
 
 
 class AnalyticalBalanceParser(AccountingDataParser):
     _filename_re = re.compile(
-        'analytical_balance_'
-        '(?P<year>[0-9]+)'
-        '_(?P<month>[0-9]+)'
-        '_(?P<day>[0-9]+)'
-        '_(?P<doctype>[^_]+)',
-        re.IGNORECASE
+        "analytical_balance_"
+        "(?P<year>[0-9]+)"
+        "_(?P<month>[0-9]+)"
+        "_(?P<day>[0-9]+)"
+        "_(?P<doctype>[^_]+)",
+        re.IGNORECASE,
     )
-    filetype = 'analytical_balance'
+    filetype = "analytical_balance"
 
     def _collect_specific_file_infos(self):
         """
@@ -440,10 +428,10 @@ class AnalyticalBalanceParser(AccountingDataParser):
 
         logger.info(u"It's an Analytical Balance file")
         self._file_datas.update(re_match.groupdict())
-        self._file_datas['date'] = datetime.date(
-            int(self._file_datas['year']),
-            int(self._file_datas['month']),
-            int(self._file_datas['day']),
+        self._file_datas["date"] = datetime.date(
+            int(self._file_datas["year"]),
+            int(self._file_datas["month"]),
+            int(self._file_datas["day"]),
         )
 
         return self._file_datas
@@ -479,9 +467,7 @@ class AnalyticalBalanceParser(AccountingDataParser):
                 )
         else:
             if line_datas:
-                logger.error(
-                    u"This line is missing informations : %s" % line_datas
-                )
+                logger.error(u"This line is missing informations : %s" % line_datas)
         return result
 
 
@@ -516,10 +502,7 @@ def send_error(request, mail_addresses, filename, err):
     """
     if mail_addresses:
         try:
-            message = MAIL_ERROR_BODY.format(
-                error=err.message,
-                filename=filename
-            )
+            message = MAIL_ERROR_BODY.format(error=err.message, filename=filename)
             subject = MAIL_ERROR_SUBJECT.format(filename=filename)
             send_mail(
                 request,
@@ -537,8 +520,7 @@ def send_unknown_error(request, mail_addresses, filename, err):
             subject = MAIL_ERROR_SUBJECT.format(filename=filename)
             print(err.message)
             message = MAIL_UNKNOWN_ERROR_BODY.format(
-                error=err.message,
-                filename=filename
+                error=err.message, filename=filename
             )
             send_mail(
                 request,
@@ -602,7 +584,7 @@ def _is_processing():
 
     :rtype: bool
     """
-    path = _get_path('processing')
+    path = _get_path("processing")
 
     for filename in os.listdir(path):
         filepath = os.path.join(path, filename)
@@ -616,7 +598,7 @@ def handle_pool_task(self, force=False):
     """
     Parse the files present in the configured file pool
     """
-    pool_path = _get_path('pool')
+    pool_path = _get_path("pool")
     waiting_file = _get_file_path_from_pool(pool_path)
 
     if waiting_file is None:
@@ -650,8 +632,7 @@ def handle_pool_task(self, force=False):
 
             transaction.begin()
             logger.info(u"  + Storing accounting operations in database")
-            upload_object_id, missed_associations, old_ids = \
-                parser.process_file()
+            upload_object_id, missed_associations, old_ids = parser.process_file()
             logger.debug(u"  + File was processed")
             transaction.commit()
         except KnownError as err:
@@ -663,7 +644,7 @@ def handle_pool_task(self, force=False):
                 logger.error(
                     u"An error mail has been sent to {0}".format(mail_addresses)
                 )
-            _mv_file(file_to_parse, 'error')
+            _mv_file(file_to_parse, "error")
             logger.error(u"File has been moved to error directory")
             return False
 
@@ -676,7 +657,7 @@ def handle_pool_task(self, force=False):
                 logger.error(
                     u"An error mail has been sent to {0}".format(mail_addresses)
                 )
-            _mv_file(file_to_parse, 'error')
+            _mv_file(file_to_parse, "error")
             logger.error(u"File has been moved to error directory")
             return False
 
@@ -721,9 +702,7 @@ def handle_pool_task(self, force=False):
                 if mail_addresses:
                     send_error(self.request, mail_addresses, filename, err)
                     logger.error(
-                        u"An error mail has been sent to {0}".format(
-                            mail_addresses
-                        )
+                        u"An error mail has been sent to {0}".format(mail_addresses)
                     )
                 logger.exception(u"* FAILED : transaction has been rollbacked")
                 return False
@@ -732,13 +711,9 @@ def handle_pool_task(self, force=False):
                 transaction.abort()
                 logger.exception(u"Unkown Error")
                 if mail_addresses:
-                    send_unknown_error(
-                        self.request, mail_addresses, filename, err
-                    )
+                    send_unknown_error(self.request, mail_addresses, filename, err)
                     logger.error(
-                        u"An error mail has been sent to {0}".format(
-                            mail_addresses
-                        )
+                        u"An error mail has been sent to {0}".format(mail_addresses)
                     )
                 logger.exception(u"* FAILED : transaction has been rollbacked")
                 return False
@@ -755,8 +730,4 @@ def handle_pool_task(self, force=False):
                 num_operations,
                 missed_associations,
             )
-            logger.info(
-                u"A success email has been sent to {0}".format(
-                    mail_addresses
-                )
-            )
+            logger.info(u"A success email has been sent to {0}".format(mail_addresses))
