@@ -47,6 +47,7 @@ from endi_celery.tasks import utils
 from endi_celery.models import (
     CsvImportJob,
 )
+
 logger = log = utils.get_logger(__name__)
 
 MISSING_KEY_ERROR = u"Erreur : Le champ {0} ({1}) est requis mais n'a pas été \
@@ -56,21 +57,20 @@ ont été détectées, nous ne sommes pas en mesure de mettre à jour ces donné
 NO_ENTRY_FOUND_ERROR = u"Aucune entrée n'a pu être retrouvée pour la clé {0} \
 avec la valeur {1}"
 NO_ID_KEY_ERROR = u"Une entrée n'a pas de valeur pour la clé {0}."
-UNFILLED_VALUES = ('', None, 0)
+UNFILLED_VALUES = ("", None, 0)
 
-BOOLEAN_FALSE = ('0', 'false', 'non', '', 'False')
+BOOLEAN_FALSE = ("0", "false", "non", "", "False")
 DATETIME_FORMAT = "%d/%m/%Y"
 
 
 DEFAULT_ID_LABEL = "Identifiant enDI"
-DEFAULT_DELIMITER = ';'
+DEFAULT_DELIMITER = ";"
 DEFAULT_QUOTECHAR = '"'
-DELIMITERS = (';', ',', ":")
+DELIMITERS = (";", ",", ":")
 QUOTECHARS = ('"', '"')
 
 
-MODELS_CONFIGURATION = {
-}
+MODELS_CONFIGURATION = {}
 
 
 def format_input_value(value, sqla_column_dict, force_rel_creation=False):
@@ -99,57 +99,63 @@ def format_input_value(value, sqla_column_dict, force_rel_creation=False):
     :rtype: object (datetime) or string depending on the column
     """
 
-    prop = sqla_column_dict['__col__']
+    prop = sqla_column_dict["__col__"]
 
     res = value
 
     if isinstance(prop, RelationshipProperty):
         # Handle the relationship
         # Get the id of the corresponding model and return it
-        if sqla_column_dict['rel_type'] == 'manytoone':
-            if 'related_retriever' in sqla_column_dict:
-                func = sqla_column_dict['related_retriever']
+        if sqla_column_dict["rel_type"] == "manytoone":
+            if "related_retriever" in sqla_column_dict:
+                func = sqla_column_dict["related_retriever"]
                 res = func(value, force_rel_creation)
             else:
-                related_key = sqla_column_dict['related_key']
+                related_key = sqla_column_dict["related_key"]
                 class_ = prop.mapper.class_
                 # We query the database to get the corresponding element
                 # filtering on the configured related_key
-                res = class_.query().filter(
-                    getattr(class_, related_key) == value
-                ).first()
+                res = (
+                    class_.query().filter(getattr(class_, related_key) == value).first()
+                )
                 if res is None and force_rel_creation:
                     if value is not None and value.strip():
-                        logger.debug("Creating a new element : %s %s" % (
-                            related_key, value)
+                        logger.debug(
+                            "Creating a new element : %s %s" % (related_key, value)
                         )
                         creation_dict = {related_key: value}
                         res = class_(**creation_dict)
         else:
             # We have a one to many relationship, we generate an instance using
             # the related_key as instanciation attribute
-            related_key = sqla_column_dict['related_key']
+            related_key = sqla_column_dict["related_key"]
             class_ = prop.mapper.class_
-            if 'formatter' in sqla_column_dict:
-                value = sqla_column_dict['formatter'](value)
+            if "formatter" in sqla_column_dict:
+                value = sqla_column_dict["formatter"](value)
             args = {related_key: value}
             res = [class_(**args)]
 
     else:
 
         column = prop.columns[0]
-        column_type = getattr(column.type, 'impl', column.type)
+        column_type = getattr(column.type, "impl", column.type)
 
-        if 'formatter' in sqla_column_dict:
-            res = sqla_column_dict['formatter'](value)
+        if "formatter" in sqla_column_dict:
+            res = sqla_column_dict["formatter"](value)
 
         elif isinstance(column_type, Boolean):
-            if value in ('0', 'false', 'non', '', 'False'):
+            if value in ("0", "false", "non", "", "False"):
                 res = False
             else:
                 res = True
 
-        elif isinstance(column_type, (DateTime, Date,)):
+        elif isinstance(
+            column_type,
+            (
+                DateTime,
+                Date,
+            ),
+        ):
             res = date_utils.str_to_date(value)
     return res
 
@@ -167,7 +173,8 @@ class CsvImportAssociator(BaseSqlaInspector):
         else:
             store_name_title_and_values_if_appoption
     """
-    config_key = 'import'
+
+    config_key = "import"
 
     def __init__(self, model, excludes=()):
         BaseSqlaInspector.__init__(self, model)
@@ -186,47 +193,45 @@ class CsvImportAssociator(BaseSqlaInspector):
             if prop.key in self.excludes:
                 continue
             info_dict = self.get_info_field(prop)
-            colanderalchemy_infos = info_dict.get('colanderalchemy', {})
+            colanderalchemy_infos = info_dict.get("colanderalchemy", {})
 
             import_dict = info_dict.get(self.config_key, {})
 
-            ui_label = colanderalchemy_infos.get('title', prop.key)
-            datas = {'name': prop.key, 'label': ui_label, '__col__': prop}
+            ui_label = colanderalchemy_infos.get("title", prop.key)
+            datas = {"name": prop.key, "label": ui_label, "__col__": prop}
             datas.update(import_dict)
 
             if isinstance(prop, RelationshipProperty):
 
                 if prop.uselist:
                     # A one to many relationship
-                    if 'related_key' not in datas:
-                        logger.debug(
-                            "Missing infos about a relationship %s" % prop.key
-                        )
+                    if "related_key" not in datas:
+                        logger.debug("Missing infos about a relationship %s" % prop.key)
                         continue
-                    datas['rel_type'] = 'onetomany'
+                    datas["rel_type"] = "onetomany"
                 else:
                     # A many to one relationship
-                    datas.setdefault('related_key', 'label')
+                    datas.setdefault("related_key", "label")
                     # We can drop the foreignky column from the importable
                     # columns to avoid misunderstanding
                     todrop.append("%s_id" % prop.key)
-                    datas['rel_type'] = 'manytoone'
+                    datas["rel_type"] = "manytoone"
             else:
                 column = prop.columns[0]
                 if not isinstance(column.default, ColumnDefault):
-                    if not column.nullable and prop.key != 'id':
-                        datas['mandatory'] = True
+                    if not column.nullable and prop.key != "id":
+                        datas["mandatory"] = True
 
-            result[datas['name']] = datas
+            result[datas["name"]] = datas
 
         for key in todrop:
             if key in result:
-                ui_label = result[key].get('label')
+                ui_label = result[key].get("label")
                 rel_key = key[:-3]
                 if rel_key in result:
-                    result[rel_key]['label'] = ui_label
-                if result[key].get('mandatory'):
-                    result[rel_key]['mandatory'] = True
+                    result[rel_key]["label"] = ui_label
+                if result[key].get("mandatory"):
+                    result[rel_key]["mandatory"] = True
                 result.pop(key)
         return result
 
@@ -253,12 +258,12 @@ class CsvImportAssociator(BaseSqlaInspector):
             if not header:
                 continue
             result[header] = None
-            toguess = header.replace('*', '').lower()
+            toguess = header.replace("*", "").lower()
             for column in self.columns.values():
-                name = column['name'].lower()
-                label = column['label'].lower()
+                name = column["name"].lower()
+                label = column["label"].lower()
                 if toguess in [name, label]:
-                    result[header] = column['name']
+                    result[header] = column["name"]
 
         if user_defined is not None:
             for key, value in user_defined.items():
@@ -277,15 +282,12 @@ class CsvImportAssociator(BaseSqlaInspector):
         if association_dict is None:
             association_dict = self.association_dict
         values = association_dict.values()
-        if 'id' not in values:
+        if "id" not in values:
             for column in self.columns.values():
-                if column.get('mandatory'):
-                    if column['name'] not in values:
+                if column.get("mandatory"):
+                    if column["name"] not in values:
                         raise MissingMandatoryArgument(
-                            MISSING_KEY_ERROR.format(
-                                column['label'],
-                                column['name']
-                            )
+                            MISSING_KEY_ERROR.format(column["label"], column["name"])
                         )
 
     def set_association_dict(self, association_dict):
@@ -314,11 +316,11 @@ class CsvImportAssociator(BaseSqlaInspector):
         for csv_key, value in csv_line.items():
             value = ascii.force_unicode(value)
 
-            if csv_key == 'id':
+            if csv_key == "id":
                 if not value:
                     column_name = None
                 else:
-                    column_name = 'id'
+                    column_name = "id"
             else:
                 key = ascii.force_unicode(csv_key)
                 column_name = self.association_dict.get(key)
@@ -409,7 +411,8 @@ class CsvImporter(object):
         association_handler = CsvImportAssociator(UserDatas)
         importer = CsvImporter(DbSession(), UserDatas, file('users.csv', 'r'),
     """
-    delimiter = ';'
+
+    delimiter = ";"
     quotechar = '"'
 
     def __init__(
@@ -437,14 +440,18 @@ class CsvImporter(object):
         self.new_count = 0
         self.update_count = 0
 
-        if action not in ("insert", "update", "override", "only_update",
-                          "only_override"):
+        if action not in (
+            "insert",
+            "update",
+            "override",
+            "only_update",
+            "only_override",
+        ):
             raise KeyError(
-                u"The action attr should be one of "
-                "(\"insert\", \"update\", \"override\")"
+                u"The action attr should be one of " '("insert", "update", "override")'
             )
 
-        if action == 'insert':
+        if action == "insert":
             self.association_handler.check_association_dict()
 
         self.action = action
@@ -454,11 +461,7 @@ class CsvImporter(object):
 
         self.quotechar = str(quotechar)
         self.delimiter = str(delimiter)
-        self.csv_reader = get_csv_reader(
-            csv_buffer,
-            self.delimiter,
-            self.quotechar
-        )
+        self.csv_reader = get_csv_reader(csv_buffer, self.delimiter, self.quotechar)
         # Importation callbacks launched after each successfull import line
         # action
         self.callbacks = callbacks
@@ -484,12 +487,8 @@ class CsvImporter(object):
             new_entry_msg = u"{0} nouvelles entrées seront créées"
             update_entry_msg = u"{0} entrées existantes seront mises à jour"
 
-        self.messages.append(
-            new_entry_msg.format(self.new_count)
-        )
-        self.messages.append(
-            update_entry_msg.format(self.update_count)
-        )
+        self.messages.append(new_entry_msg.format(self.new_count))
+        self.messages.append(update_entry_msg.format(self.update_count))
 
     def _insert(self, args, persist=True):
         """
@@ -542,9 +541,11 @@ class CsvImporter(object):
 
             try:
 
-                model = self.factory.query().filter(
-                    identification_column == identification_value
-                ).one()
+                model = (
+                    self.factory.query()
+                    .filter(identification_column == identification_value)
+                    .one()
+                )
 
                 for key, value in self.default_init_values.items():
                     if getattr(model, key) != value:
@@ -565,15 +566,12 @@ class CsvImporter(object):
             except sqlalchemy_exc.NoResultFound:
                 if not insert:
                     raise MultipleInstanceFound(
-                        NO_ENTRY_FOUND_ERROR.format(
-                            self.id_key,
-                            identification_value
-                        )
+                        NO_ENTRY_FOUND_ERROR.format(self.id_key, identification_value)
                     )
                 # We first restore the poped identification column (if it's not
                 # the id key: id key should not be set but email can be used as
                 # identification key and should be set for new entries)
-                if self.id_key != 'id':
+                if self.id_key != "id":
                     args[self.id_key] = identification_value
                 model, updated = self._insert(args, persist=persist)
 
@@ -591,9 +589,7 @@ class CsvImporter(object):
         :returns: a tuple (model, updated_token) where updated_token is a
         boolean saying if it's an update
         """
-        return self._update(
-            args, override=False, persist=persist, insert=False
-        )
+        return self._update(args, override=False, persist=persist, insert=False)
 
     def _override(self, args, persist=True):
         """
@@ -662,6 +658,7 @@ class CsvImporter(object):
                 self.launch_callbacks(model, updated, args)
         except OperationalError as error:
             import traceback
+
             traceback.print_exc()
             res = None
             self.in_error_lines.append(line)
@@ -673,6 +670,7 @@ class CsvImporter(object):
             )
         except Exception as e:
             import traceback
+
             traceback.print_exc()
             log.exception(u"Erreur lors de l'import de données")
             self.in_error_lines.append(line)
@@ -698,7 +696,7 @@ class CsvImporter(object):
                 fieldnames,
                 delimiter=self.delimiter,
                 quotechar=self.quotechar,
-                extrasaction='ignore',
+                extrasaction="ignore",
                 quoting=csv.QUOTE_ALL,
             )
             writer.writeheader()
@@ -719,7 +717,7 @@ class CsvImporter(object):
             in_error_lines_csv=in_error_lines_csv,
             messages=self.messages,
             error_messages=self.err_messages,
-            status='done',
+            status="done",
         )
         return result
 
@@ -737,8 +735,8 @@ def get_csv_importer(
     quotechar=DEFAULT_QUOTECHAR,
 ):
 
-    factory = MODELS_CONFIGURATION[model_type]['factory']
-    callbacks = MODELS_CONFIGURATION[model_type]['callbacks']
+    factory = MODELS_CONFIGURATION[model_type]["factory"]
+    callbacks = MODELS_CONFIGURATION[model_type]["callbacks"]
     return CsvImporter(
         dbsession,
         factory,
@@ -759,8 +757,7 @@ def get_csv_import_associator(key):
     Build a csv import associator regarding the provided model
     """
     return CsvImportAssociator(
-        MODELS_CONFIGURATION[key]['factory'],
-        MODELS_CONFIGURATION[key]['excludes']
+        MODELS_CONFIGURATION[key]["factory"], MODELS_CONFIGURATION[key]["excludes"]
     )
 
 
@@ -768,8 +765,17 @@ def get_csv_import_associator(key):
 # method and thus we can access attributes like request
 @celery_app.task(bind=True)
 def async_import_datas(
-    self, model_type, job_id, association_dict, csv_filepath, id_key, action,
-    force_rel_creation, default_values, delimiter, quotechar
+    self,
+    model_type,
+    job_id,
+    association_dict,
+    csv_filepath,
+    id_key,
+    action,
+    force_rel_creation,
+    default_values,
+    delimiter,
+    quotechar,
 ):
     """
     Launch the import of the datas provided in the csv_filepath
@@ -800,10 +806,11 @@ def async_import_datas(
     utils.start_job(self.request, CsvImportJob, job_id)
 
     from endi_base.models.base import DBSESSION
+
     try:
         associator = get_csv_import_associator(model_type)
         associator.set_association_dict(association_dict)
-        csv_buffer = open(csv_filepath, 'r')
+        csv_buffer = open(csv_filepath, "r")
         importer = get_csv_importer(
             DBSESSION(),
             model_type,
@@ -822,7 +829,7 @@ def async_import_datas(
     except Exception as e:
         transaction.abort()
         logger.exception(u"The transaction has been aborted")
-        utils.record_failure(CsvImportJob, job_id, e)
+        utils.record_failure(CsvImportJob, job_id, [e])
     else:
         logger.info(u"We update the job informations")
         utils.record_completed(CsvImportJob, job_id, **importer.log())
